The symbols library parses the symbols data file and returns the collection of SymbolMetadata objects.
Modules
- extensions
- Extension methods
Structs
Functions
- read_
symbols - Read and parse the symbols collection.
The symbols library parses the symbols data file and returns the collection of SymbolMetadata objects.